intelmq.bots.outputs.files package — intelmq 2.3.3.alpha1 documentation

# intelmq.bots.outputs.files package

## Submodules

## intelmq.bots.outputs.files.output module

`intelmq.bots.outputs.files.output.` `BOT`

  alias of `intelmq.bots.outputs.files.output.FilesOutputBot`

class `intelmq.bots.outputs.files.output.` `FilesOutputBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.OutputBot`

  `_get_new_name`(fd=None)

    Creates unique filename (Maildir inspired)

  `create_unique_file`()

    Safely creates machine-wide uniquely named file in tmp dir.

  `init`()
  `process`()

## Module contents